@@ -1,4 +1,5 @@
-from typing import Dict, List
+from typing import Dict
+from typing import List
 
 
 def to_num(text: str) -> int or float:
