@@ -21,7 +21,7 @@
 
         from salt.serializers import yamlex
 
-        with open('state.sls', 'r') as stream:
+        with open("state.sls", "r") as stream:
             obj = yamlex.deserialize(stream)
 
     Check that ``obj`` is an OrderedDict
@@ -40,7 +40,7 @@
 
     .. code-block:: python
 
-        print '{0}'.format(obj)
+        print "{0}".format(obj)
 
     returns:
 
@@ -53,6 +53,7 @@
     .. code-block:: python
 
         from salt.serializers import yaml
+
         yml_obj = yaml.deserialize(str(obj))
         assert yml_obj == obj
 
@@ -319,13 +320,15 @@ class SLSMap(collections.OrderedDict):
 
     .. code-block:: python
 
-        >>> mapping = OrderedDict([('a', 'b'), ('c', None)])
-        >>> print mapping
-        OrderedDict([('a', 'b'), ('c', None)])
+        from collections import OrderedDict
 
-        >>> sls_map = SLSMap(mapping)
-        >>> print sls_map.__str__()
-        {a: b, c: null}
+        mapping = OrderedDict([("a", "b"), ("c", None)])
+        print(mapping)
+        # OrderedDict([('a', 'b'), ('c', None)])
+
+        sls_map = SLSMap(mapping)
+        print(sls_map.__str__())
+        # {a: b, c: null}
 
     """
 
@@ -342,13 +345,13 @@ class SLSString(str):
 
     .. code-block:: python
 
-        >>> scalar = str('foo')
-        >>> print 'foo'
-        foo
+        scalar = str("foo")
+        print "foo"
+        # foo
 
-        >>> sls_scalar = SLSString(scalar)
-        >>> print sls_scalar
-        "foo"
+        sls_scalar = SLSString(scalar)
+        print (sls_scalar)
+        # "foo"
 
     """
 
